==> apache-beam-2.5.0-source-release.zip: beam-release-2.5.0/sdks/java/io/kinesis/src/main/java/org/apache/beam/sdk/io/kinesis/GetKinesisRecordsResult.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.beam.sdk.io.kinesis;

import com.amazonaws.services.kinesis.clientlibrary.types.UserRecord;
import java.util.List;
import java.util.stream.Collectors;

/**
 * Represents the output of 'get' operation on Kinesis stream.
 */
class GetKinesisRecordsResult {

  private final List<KinesisRecord> records;
  private final String nextShardIterator;
  private final long millisBehindLatest;

  public GetKinesisRecordsResult(List<UserRecord> records, String nextShardIterator,
      long millisBehindLatest, final String streamName, final String shardId) {
    this.records = records.stream().map(input -> {
      assert input != null;  // to make FindBugs happy
      return new KinesisRecord(input, streamName, shardId);
    }).collect(Collectors.toList());
    this.nextShardIterator = nextShardIterator;
    this.millisBehindLatest = millisBehindLatest;
  }

  public List<KinesisRecord> getRecords() {
    return records;
  }

  public String getNextShardIterator() {
    return nextShardIterator;
  }

  public long getMillisBehindLatest() {
    return millisBehindLatest;
  }
}

==> apache-beam-2.9.0-source-release.zip: beam-release-2.9.0/sdks/java/io/kinesis/src/main/java/org/apache/beam/sdk/io/kinesis/GetKinesisRecordsResult.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.beam.sdk.io.kinesis;

import com.amazonaws.services.kinesis.clientlibrary.types.UserRecord;
import java.util.List;
import java.util.stream.Collectors;

/** Represents the output of 'get' operation on Kinesis stream. */
class GetKinesisRecordsResult {

  private final List<KinesisRecord> records;
  private final String nextShardIterator;
  private final long millisBehindLatest;

  public GetKinesisRecordsResult(
      List<UserRecord> records,
      String nextShardIterator,
      long millisBehindLatest,
      final String streamName,
      final String shardId) {
    this.records =
        records
            .stream()
            .map(
                input -> {
                  assert input != null; // to make FindBugs happy
                  return new KinesisRecord(input, streamName, shardId);
                })
            .collect(Collectors.toList());
    this.nextShardIterator = nextShardIterator;
    this.millisBehindLatest = millisBehindLatest;
  }

  public List<KinesisRecord> getRecords() {
    return records;
  }

  public String getNextShardIterator() {
    return nextShardIterator;
  }

  public long getMillisBehindLatest() {
    return millisBehindLatest;
  }
}
